SamplingToastDataSource
=======================

.. currentmodule:: toasty.toast

.. autoclass:: SamplingToastDataSource
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SamplingToastDataSource.sample_layer

   .. rubric:: Methods Documentation

   .. automethod:: sample_layer
